@@ -29,7 +29,11 @@ import aws_cdk.core
 
 
 @jsii.implements(aws_cdk.core.IInspectable)
-class CfnAssessmentTarget(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-inspector.CfnAssessmentTarget"):
+class CfnAssessmentTarget(
+    aws_cdk.core.CfnResource,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@aws-cdk/aws-inspector.CfnAssessmentTarget",
+):
     """A CloudFormation ``AWS::Inspector::AssessmentTarget``.
 
     see
@@ -37,7 +41,15 @@ class CfnAssessmentTarget(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsi
     cloudformationResource:
     :cloudformationResource:: AWS::Inspector::AssessmentTarget
     """
-    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, assessment_target_name: typing.Optional[str]=None, resource_group_arn: typing.Optional[str]=None) -> None:
+
+    def __init__(
+        self,
+        scope: aws_cdk.core.Construct,
+        id: str,
+        *,
+        assessment_target_name: typing.Optional[str] = None,
+        resource_group_arn: typing.Optional[str] = None,
+    ) -> None:
         """Create a new ``AWS::Inspector::AssessmentTarget``.
 
         :param scope: - scope in which this resource is defined.
@@ -45,13 +57,23 @@ class CfnAssessmentTarget(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsi
         :param assessment_target_name: ``AWS::Inspector::AssessmentTarget.AssessmentTargetName``.
         :param resource_group_arn: ``AWS::Inspector::AssessmentTarget.ResourceGroupArn``.
         """
-        props = CfnAssessmentTargetProps(assessment_target_name=assessment_target_name, resource_group_arn=resource_group_arn)
+        props = CfnAssessmentTargetProps(
+            assessment_target_name=assessment_target_name,
+            resource_group_arn=resource_group_arn,
+        )
 
         jsii.create(CfnAssessmentTarget, self, [scope, id, props])
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: aws_cdk.core.Construct, id: str, resource_attributes: typing.Any, *, finder: aws_cdk.core.ICfnFinder) -> "CfnAssessmentTarget":
+    def from_cloud_formation(
+        cls,
+        scope: aws_cdk.core.Construct,
+        id: str,
+        resource_attributes: typing.Any,
+        *,
+        finder: aws_cdk.core.ICfnFinder,
+    ) -> "CfnAssessmentTarget":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -66,7 +88,9 @@ class CfnAssessmentTarget(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsi
         """
         options = aws_cdk.core.FromCloudFormationOptions(finder=finder)
 
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
+        return jsii.sinvoke(
+            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
+        )
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
@@ -80,7 +104,9 @@ class CfnAssessmentTarget(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsi
         return jsii.invoke(self, "inspect", [inspector])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
+    def _render_properties(
+        self, props: typing.Mapping[str, typing.Any]
+    ) -> typing.Mapping[str, typing.Any]:
         """
         :param props: -
         """
@@ -135,9 +161,21 @@ class CfnAssessmentTarget(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsi
         jsii.set(self, "resourceGroupArn", value)
 
 
-@jsii.data_type(jsii_type="@aws-cdk/aws-inspector.CfnAssessmentTargetProps", jsii_struct_bases=[], name_mapping={'assessment_target_name': 'assessmentTargetName', 'resource_group_arn': 'resourceGroupArn'})
-class CfnAssessmentTargetProps():
-    def __init__(self, *, assessment_target_name: typing.Optional[str]=None, resource_group_arn: typing.Optional[str]=None) -> None:
+@jsii.data_type(
+    jsii_type="@aws-cdk/aws-inspector.CfnAssessmentTargetProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "assessment_target_name": "assessmentTargetName",
+        "resource_group_arn": "resourceGroupArn",
+    },
+)
+class CfnAssessmentTargetProps:
+    def __init__(
+        self,
+        *,
+        assessment_target_name: typing.Optional[str] = None,
+        resource_group_arn: typing.Optional[str] = None,
+    ) -> None:
         """Properties for defining a ``AWS::Inspector::AssessmentTarget``.
 
         :param assessment_target_name: ``AWS::Inspector::AssessmentTarget.AssessmentTargetName``.
@@ -146,10 +184,11 @@ class CfnAssessmentTargetProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttarget.html
         """
-        self._values = {
-        }
-        if assessment_target_name is not None: self._values["assessment_target_name"] = assessment_target_name
-        if resource_group_arn is not None: self._values["resource_group_arn"] = resource_group_arn
+        self._values = {}
+        if assessment_target_name is not None:
+            self._values["assessment_target_name"] = assessment_target_name
+        if resource_group_arn is not None:
+            self._values["resource_group_arn"] = resource_group_arn
 
     @builtins.property
     def assessment_target_name(self) -> typing.Optional[str]:
@@ -158,7 +197,7 @@ class CfnAssessmentTargetProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttarget.html#cfn-inspector-assessmenttarget-assessmenttargetname
         """
-        return self._values.get('assessment_target_name')
+        return self._values.get("assessment_target_name")
 
     @builtins.property
     def resource_group_arn(self) -> typing.Optional[str]:
@@ -167,7 +206,7 @@ class CfnAssessmentTargetProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttarget.html#cfn-inspector-assessmenttarget-resourcegrouparn
         """
-        return self._values.get('resource_group_arn')
+        return self._values.get("resource_group_arn")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -176,11 +215,17 @@ class CfnAssessmentTargetProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'CfnAssessmentTargetProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "CfnAssessmentTargetProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 @jsii.implements(aws_cdk.core.IInspectable)
-class CfnAssessmentTemplate(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-inspector.CfnAssessmentTemplate"):
+class CfnAssessmentTemplate(
+    aws_cdk.core.CfnResource,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@aws-cdk/aws-inspector.CfnAssessmentTemplate",
+):
     """A CloudFormation ``AWS::Inspector::AssessmentTemplate``.
 
     see
@@ -188,7 +233,25 @@ class CfnAssessmentTemplate(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, j
     cloudformationResource:
     :cloudformationResource:: AWS::Inspector::AssessmentTemplate
     """
-    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, assessment_target_arn: str, duration_in_seconds: jsii.Number, rules_package_arns: typing.List[str], assessment_template_name: typing.Optional[str]=None, user_attributes_for_findings: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]]=None) -> None:
+
+    def __init__(
+        self,
+        scope: aws_cdk.core.Construct,
+        id: str,
+        *,
+        assessment_target_arn: str,
+        duration_in_seconds: jsii.Number,
+        rules_package_arns: typing.List[str],
+        assessment_template_name: typing.Optional[str] = None,
+        user_attributes_for_findings: typing.Optional[
+            typing.Union[
+                aws_cdk.core.IResolvable,
+                typing.List[
+                    typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]
+                ],
+            ]
+        ] = None,
+    ) -> None:
         """Create a new ``AWS::Inspector::AssessmentTemplate``.
 
         :param scope: - scope in which this resource is defined.
@@ -199,13 +262,26 @@ class CfnAssessmentTemplate(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, j
         :param assessment_template_name: ``AWS::Inspector::AssessmentTemplate.AssessmentTemplateName``.
         :param user_attributes_for_findings: ``AWS::Inspector::AssessmentTemplate.UserAttributesForFindings``.
         """
-        props = CfnAssessmentTemplateProps(assessment_target_arn=assessment_target_arn, duration_in_seconds=duration_in_seconds, rules_package_arns=rules_package_arns, assessment_template_name=assessment_template_name, user_attributes_for_findings=user_attributes_for_findings)
+        props = CfnAssessmentTemplateProps(
+            assessment_target_arn=assessment_target_arn,
+            duration_in_seconds=duration_in_seconds,
+            rules_package_arns=rules_package_arns,
+            assessment_template_name=assessment_template_name,
+            user_attributes_for_findings=user_attributes_for_findings,
+        )
 
         jsii.create(CfnAssessmentTemplate, self, [scope, id, props])
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: aws_cdk.core.Construct, id: str, resource_attributes: typing.Any, *, finder: aws_cdk.core.ICfnFinder) -> "CfnAssessmentTemplate":
+    def from_cloud_formation(
+        cls,
+        scope: aws_cdk.core.Construct,
+        id: str,
+        resource_attributes: typing.Any,
+        *,
+        finder: aws_cdk.core.ICfnFinder,
+    ) -> "CfnAssessmentTemplate":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -220,7 +296,9 @@ class CfnAssessmentTemplate(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, j
         """
         options = aws_cdk.core.FromCloudFormationOptions(finder=finder)
 
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
+        return jsii.sinvoke(
+            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
+        )
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
@@ -234,7 +312,9 @@ class CfnAssessmentTemplate(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, j
         return jsii.invoke(self, "inspect", [inspector])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
+    def _render_properties(
+        self, props: typing.Mapping[str, typing.Any]
+    ) -> typing.Mapping[str, typing.Any]:
         """
         :param props: -
         """
@@ -318,7 +398,14 @@ class CfnAssessmentTemplate(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, j
 
     @builtins.property
     @jsii.member(jsii_name="userAttributesForFindings")
-    def user_attributes_for_findings(self) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]]:
+    def user_attributes_for_findings(
+        self,
+    ) -> typing.Optional[
+        typing.Union[
+            aws_cdk.core.IResolvable,
+            typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]],
+        ]
+    ]:
         """``AWS::Inspector::AssessmentTemplate.UserAttributesForFindings``.
 
         see
@@ -327,13 +414,48 @@ class CfnAssessmentTemplate(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, j
         return jsii.get(self, "userAttributesForFindings")
 
     @user_attributes_for_findings.setter
-    def user_attributes_for_findings(self, value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]]) -> None:
+    def user_attributes_for_findings(
+        self,
+        value: typing.Optional[
+            typing.Union[
+                aws_cdk.core.IResolvable,
+                typing.List[
+                    typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]
+                ],
+            ]
+        ],
+    ) -> None:
         jsii.set(self, "userAttributesForFindings", value)
 
 
-@jsii.data_type(jsii_type="@aws-cdk/aws-inspector.CfnAssessmentTemplateProps", jsii_struct_bases=[], name_mapping={'assessment_target_arn': 'assessmentTargetArn', 'duration_in_seconds': 'durationInSeconds', 'rules_package_arns': 'rulesPackageArns', 'assessment_template_name': 'assessmentTemplateName', 'user_attributes_for_findings': 'userAttributesForFindings'})
-class CfnAssessmentTemplateProps():
-    def __init__(self, *, assessment_target_arn: str, duration_in_seconds: jsii.Number, rules_package_arns: typing.List[str], assessment_template_name: typing.Optional[str]=None, user_attributes_for_findings: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]]=None) -> None:
+@jsii.data_type(
+    jsii_type="@aws-cdk/aws-inspector.CfnAssessmentTemplateProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "assessment_target_arn": "assessmentTargetArn",
+        "duration_in_seconds": "durationInSeconds",
+        "rules_package_arns": "rulesPackageArns",
+        "assessment_template_name": "assessmentTemplateName",
+        "user_attributes_for_findings": "userAttributesForFindings",
+    },
+)
+class CfnAssessmentTemplateProps:
+    def __init__(
+        self,
+        *,
+        assessment_target_arn: str,
+        duration_in_seconds: jsii.Number,
+        rules_package_arns: typing.List[str],
+        assessment_template_name: typing.Optional[str] = None,
+        user_attributes_for_findings: typing.Optional[
+            typing.Union[
+                aws_cdk.core.IResolvable,
+                typing.List[
+                    typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]
+                ],
+            ]
+        ] = None,
+    ) -> None:
         """Properties for defining a ``AWS::Inspector::AssessmentTemplate``.
 
         :param assessment_target_arn: ``AWS::Inspector::AssessmentTemplate.AssessmentTargetArn``.
@@ -346,12 +468,14 @@ class CfnAssessmentTemplateProps():
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html
         """
         self._values = {
-            'assessment_target_arn': assessment_target_arn,
-            'duration_in_seconds': duration_in_seconds,
-            'rules_package_arns': rules_package_arns,
+            "assessment_target_arn": assessment_target_arn,
+            "duration_in_seconds": duration_in_seconds,
+            "rules_package_arns": rules_package_arns,
         }
-        if assessment_template_name is not None: self._values["assessment_template_name"] = assessment_template_name
-        if user_attributes_for_findings is not None: self._values["user_attributes_for_findings"] = user_attributes_for_findings
+        if assessment_template_name is not None:
+            self._values["assessment_template_name"] = assessment_template_name
+        if user_attributes_for_findings is not None:
+            self._values["user_attributes_for_findings"] = user_attributes_for_findings
 
     @builtins.property
     def assessment_target_arn(self) -> str:
@@ -360,7 +484,7 @@ class CfnAssessmentTemplateProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-assessmenttargetarn
         """
-        return self._values.get('assessment_target_arn')
+        return self._values.get("assessment_target_arn")
 
     @builtins.property
     def duration_in_seconds(self) -> jsii.Number:
@@ -369,7 +493,7 @@ class CfnAssessmentTemplateProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-durationinseconds
         """
-        return self._values.get('duration_in_seconds')
+        return self._values.get("duration_in_seconds")
 
     @builtins.property
     def rules_package_arns(self) -> typing.List[str]:
@@ -378,7 +502,7 @@ class CfnAssessmentTemplateProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-rulespackagearns
         """
-        return self._values.get('rules_package_arns')
+        return self._values.get("rules_package_arns")
 
     @builtins.property
     def assessment_template_name(self) -> typing.Optional[str]:
@@ -387,16 +511,23 @@ class CfnAssessmentTemplateProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-assessmenttemplatename
         """
-        return self._values.get('assessment_template_name')
+        return self._values.get("assessment_template_name")
 
     @builtins.property
-    def user_attributes_for_findings(self) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]]:
+    def user_attributes_for_findings(
+        self,
+    ) -> typing.Optional[
+        typing.Union[
+            aws_cdk.core.IResolvable,
+            typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]],
+        ]
+    ]:
         """``AWS::Inspector::AssessmentTemplate.UserAttributesForFindings``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-assessmenttemplate.html#cfn-inspector-assessmenttemplate-userattributesforfindings
         """
-        return self._values.get('user_attributes_for_findings')
+        return self._values.get("user_attributes_for_findings")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -405,11 +536,17 @@ class CfnAssessmentTemplateProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'CfnAssessmentTemplateProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "CfnAssessmentTemplateProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 @jsii.implements(aws_cdk.core.IInspectable)
-class CfnResourceGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-inspector.CfnResourceGroup"):
+class CfnResourceGroup(
+    aws_cdk.core.CfnResource,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@aws-cdk/aws-inspector.CfnResourceGroup",
+):
     """A CloudFormation ``AWS::Inspector::ResourceGroup``.
 
     see
@@ -417,7 +554,17 @@ class CfnResourceGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_t
     cloudformationResource:
     :cloudformationResource:: AWS::Inspector::ResourceGroup
     """
-    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, resource_group_tags: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]) -> None:
+
+    def __init__(
+        self,
+        scope: aws_cdk.core.Construct,
+        id: str,
+        *,
+        resource_group_tags: typing.Union[
+            aws_cdk.core.IResolvable,
+            typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]],
+        ],
+    ) -> None:
         """Create a new ``AWS::Inspector::ResourceGroup``.
 
         :param scope: - scope in which this resource is defined.
@@ -430,7 +577,14 @@ class CfnResourceGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_t
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: aws_cdk.core.Construct, id: str, resource_attributes: typing.Any, *, finder: aws_cdk.core.ICfnFinder) -> "CfnResourceGroup":
+    def from_cloud_formation(
+        cls,
+        scope: aws_cdk.core.Construct,
+        id: str,
+        resource_attributes: typing.Any,
+        *,
+        finder: aws_cdk.core.ICfnFinder,
+    ) -> "CfnResourceGroup":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -445,7 +599,9 @@ class CfnResourceGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_t
         """
         options = aws_cdk.core.FromCloudFormationOptions(finder=finder)
 
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
+        return jsii.sinvoke(
+            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
+        )
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
@@ -459,7 +615,9 @@ class CfnResourceGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_t
         return jsii.invoke(self, "inspect", [inspector])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
+    def _render_properties(
+        self, props: typing.Mapping[str, typing.Any]
+    ) -> typing.Mapping[str, typing.Any]:
         """
         :param props: -
         """
@@ -487,7 +645,12 @@ class CfnResourceGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_t
 
     @builtins.property
     @jsii.member(jsii_name="resourceGroupTags")
-    def resource_group_tags(self) -> typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]:
+    def resource_group_tags(
+        self,
+    ) -> typing.Union[
+        aws_cdk.core.IResolvable,
+        typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]],
+    ]:
         """``AWS::Inspector::ResourceGroup.ResourceGroupTags``.
 
         see
@@ -496,13 +659,30 @@ class CfnResourceGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_t
         return jsii.get(self, "resourceGroupTags")
 
     @resource_group_tags.setter
-    def resource_group_tags(self, value: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]) -> None:
+    def resource_group_tags(
+        self,
+        value: typing.Union[
+            aws_cdk.core.IResolvable,
+            typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]],
+        ],
+    ) -> None:
         jsii.set(self, "resourceGroupTags", value)
 
 
-@jsii.data_type(jsii_type="@aws-cdk/aws-inspector.CfnResourceGroupProps", jsii_struct_bases=[], name_mapping={'resource_group_tags': 'resourceGroupTags'})
-class CfnResourceGroupProps():
-    def __init__(self, *, resource_group_tags: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]) -> None:
+@jsii.data_type(
+    jsii_type="@aws-cdk/aws-inspector.CfnResourceGroupProps",
+    jsii_struct_bases=[],
+    name_mapping={"resource_group_tags": "resourceGroupTags"},
+)
+class CfnResourceGroupProps:
+    def __init__(
+        self,
+        *,
+        resource_group_tags: typing.Union[
+            aws_cdk.core.IResolvable,
+            typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]],
+        ],
+    ) -> None:
         """Properties for defining a ``AWS::Inspector::ResourceGroup``.
 
         :param resource_group_tags: ``AWS::Inspector::ResourceGroup.ResourceGroupTags``.
@@ -511,17 +691,22 @@ class CfnResourceGroupProps():
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-resourcegroup.html
         """
         self._values = {
-            'resource_group_tags': resource_group_tags,
+            "resource_group_tags": resource_group_tags,
         }
 
     @builtins.property
-    def resource_group_tags(self) -> typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]]]:
+    def resource_group_tags(
+        self,
+    ) -> typing.Union[
+        aws_cdk.core.IResolvable,
+        typing.List[typing.Union[aws_cdk.core.CfnTag, aws_cdk.core.IResolvable]],
+    ]:
         """``AWS::Inspector::ResourceGroup.ResourceGroupTags``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-inspector-resourcegroup.html#cfn-inspector-resourcegroup-resourcegrouptags
         """
-        return self._values.get('resource_group_tags')
+        return self._values.get("resource_group_tags")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -530,7 +715,9 @@ class CfnResourceGroupProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'CfnResourceGroupProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "CfnResourceGroupProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 __all__ = [
